@@ -15,6 +15,7 @@ our @EXPORT_OK;
 
 use XML::LibXML;
 use File::Slurp qw/read_file/;
+use XMLTV::Supplement qw/GetSupplement/;
 
 our $REQUIRE_CHANNEL_ID=1;
 
@@ -54,10 +55,6 @@ sub LoadDtd {
 	or die "Failed to read $dtd_file";
 
     $dtd = XML::LibXML::Dtd->parse_string($dtd_str);
-    
-    $parser = XML::LibXML->new();
-    $parser->line_numbers(1);
-    
 }
 
 =item ValidateFile
@@ -124,6 +121,10 @@ A programme entry with an invalid start-time was found.
 
 A programme entry with an invalid stop-time was found.
 
+=item badepisode
+
+A programme entry with an invalid episode number was found.
+
 =back
 
 If no errors are found, an empty list is returned.
@@ -136,8 +137,15 @@ my %timezoneerrors;
 sub ValidateFile {
     my( $file ) = @_;
 
-    die "ValidateFile called without previous call to LoadDtd" 
-	unless defined $dtd;
+    if( not defined( $parser ) ) {
+	$parser = XML::LibXML->new();
+	$parser->line_numbers(1);
+    }
+
+    if( not defined( $dtd ) ) {
+	my $dtd_str = GetSupplement( undef, 'xmltv.dtd');
+	$dtd = XML::LibXML::Dtd->parse_string( $dtd_str );
+    }
 
     %errors = ();
 
@@ -218,9 +226,9 @@ sub ValidateFile {
 
 	if( $xmltv_episode =~ /\S/ ) {
 	    $w->($p, "Invalid episode-number '$xmltv_episode'", 'badepisode' )
-		if $xmltv_episode !~ /^\s*\d*(\/\s*\d+)*\s*\. 
-		                       \s*\d*(\/\s*\d+)*\s*\. 
-		                       \s*\d*(\/\s*\d+)*\s*$/x; 
+		if $xmltv_episode !~ /^\s*\d* (\s* \/ \s*\d+)? \s* \. 
+		                       \s*\d* (\s* \/ \s*\d+)? \s* \. 
+		                       \s*\d* (\s* \/ \s*\d+)? \s* $/x; 
 	}
     }
 
