@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_opt.pl,v 1.15 2008/11/30 06:49:12 rmeden Exp $
+# $Id: exe_opt.pl,v 1.17 2009/09/16 03:34:37 rmeden Exp $
 #
 # This is a simple script to generate options so PerlApp can make the EXE
 # it needs time values, so might as well put it in a perl script!
@@ -21,9 +21,14 @@ print '-nologo
 -add="XMLTV::GUI"
 -add="Class::MethodMaker::scalar"
 -add="Tk::ProgressBar"
+-trim="Net::FTP::A"
+-trim="B"
 -bind=libxml2.dll[file=\perl\bin\libxml2.dll,extract]
 -trim="Apache::Const;Apache::RequestIO;DIME::Payload;MIME::Entity;Apache::RequestRec;DIME::Message;I18N::Langinfo"
 -trim="Apache2::RequestUtil;APR::Table;Apache2::Const;Apache2::RequestRec;Apache2::RequestIO"
+-trim=DateTime::Format
+-trim=DateTime::Locale
+-trim=grab/eu_epgdata/tv_grab_eu_epgdata
 -info CompanyName="XMLTV Project http://www.xmltv.org"
 -info FileDescription="EXE bundle of XMLTV tools to manage TV Listings"
 -info InternalName=xmltv.exe
