@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.82 2009/03/14 07:15:14 rmeden Exp $
+# $Id: exe_wrap.pl,v 1.85 2010/04/19 04:52:12 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -69,7 +69,7 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.55';
+my $VERSION = '0.5.57';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -78,7 +78,7 @@ if (index('--version', $cmd) == 0 and length $cmd >= 3) {
 #
 # some grabbers aren't included
 #
-if ($cmd =~ /^tv_grab_(?:nz|jp)$/) {
+if ($cmd =~ /^tv_grab_(?:nz|jp|epgdata)$/) {
     die <<END
 Sorry, $cmd is not available in this Windows binary release, although
 it is included in xmltv source releases.
